# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: Disease.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'Disease.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
import Code_pb2 as Code__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rDisease.proto\x12\x04nuva\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\nCode.proto\"\xe9\x01\n\x07\x44isease\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\r\x12\x19\n\x05\x63odes\x18\x04 \x03(\x0b\x32\n.nuva.Code\x12\x12\n\nvaccinable\x18\x05 \x01(\x08\x12\x12\n\nscreenable\x18\x06 \x01(\x08\x12\x13\n\x0bvalence_ids\x18\x07 \x03(\t\x12.\n\ncreated_at\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.TimestampB!\n\x0f\x63om.syadem.nuvaP\x01\xaa\x02\x0bSyadem.Nuvab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'Disease_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017com.syadem.nuvaP\001\252\002\013Syadem.Nuva'
  _globals['_DISEASE']._serialized_start=69
  _globals['_DISEASE']._serialized_end=302
# @@protoc_insertion_point(module_scope)
